# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!--
The rules for this file:
  * entries are sorted newest-first.
  * summarize sets of changes - don't reproduce every git log comment here.
  * don't ever delete anything.
  * keep the format consistent:
    * do not use tabs but use spaces for formatting
    * 79 char width
    * YYYY-MM-DD date format (following ISO 8601)
  * accompany each entry with github issue/PR number (Issue #xyz)
-->

## [Unreleased]

### Authors
<!-- GitHub usernames of contributors to this release -->

### Added
<!-- New added features -->

### Fixed
<!-- Bug fixes -->

### Changed
<!-- Changes in existing functionality -->

### Deprecated
<!-- Soon-to-be removed features -->

### Removed
<!-- Removed features -->

## [0.2.0] - 2023-09-21

### Authors
<!-- GitHub usernames of contributors to this release -->
p-j-smith

### Added
<!-- New added features -->
- added nojump, wrap, and unwrap transformations

## [0.1.1] - 2023-09-11

### Authors
<!-- GitHub usernames of contributors to this release -->
p-j-smtih

### Fixed
<!-- Bug fixes -->
- fix version number of wheels uploaded to PyPI

## [0.1.0] - 2023-09-11

### Authors
<!-- GitHub usernames of contributors to this release -->
- p-j-smith

### Added
<!-- New added features -->
- first relase of mda-tui - includes transformations for translating
atom groups or centering them in a box
